@@ -250,11 +250,7 @@ impl PtyProcess {
     ///
     /// It's a non blocking operation.
     pub fn is_alive(&self) -> Result<bool> {
-        match self.status() {
-            Ok(status) if status == WaitStatus::StillAlive => Ok(true),
-            Ok(_) | Err(Error::Sys(Errno::ECHILD)) | Err(Error::Sys(Errno::ESRCH)) => Ok(false),
-            Err(err) => Err(err),
-        }
+        is_alive(self.status())
     }
 
     /// Try to force a child to terminate.
@@ -364,43 +360,6 @@ impl PtyProcess {
     pub fn send_intr(&mut self) -> io::Result<()> {
         self.stream.write_all(&[self.intr_char])
     }
-
-    /// Interact gives control of the child process to the interactive user (the
-    /// human at the keyboard).
-    ///
-    /// Keystrokes are sent to the child process, and
-    /// the `stdout` and `stderr` output of the child process is printed.
-    ///
-    /// When the user types the `escape_character` this method will return control to a running process.
-    /// The escape_character will not be transmitted.
-    /// The default for escape_character is entered as `Ctrl-]`, the very same as BSD telnet.
-    ///
-    /// This simply echos the child `stdout` and `stderr` to the real `stdout` and
-    /// it echos the real `stdin` to the child `stdin`.
-    pub fn interact(&mut self) -> io::Result<()> {
-        // flush buffers
-        self.flush()?;
-
-        let stdin = unsafe { std::fs::File::from_raw_fd(std::io::stdin().as_raw_fd()) };
-        let mut stdin_stream = Stream::new(stdin);
-        let mut buf = [0; 512];
-        loop {
-            if let Some(n) = self.try_read(&mut buf)? {
-                std::io::stdout().write_all(&buf[..n])?;
-            }
-
-            if let Some(n) = stdin_stream.try_read(&mut buf)? {
-                for i in 0..n {
-                    if buf[i] == ControlCode::GroupSeparator as u8 {
-                        // Ctrl-]
-                        return Ok(());
-                    }
-
-                    self.write_all(&buf[i..i + 1])?;
-                }
-            }
-        }
-    }
 }
 
 #[cfg(feature = "async")]
@@ -464,43 +423,6 @@ impl PtyProcess {
     pub async fn send_intr(&mut self) -> io::Result<()> {
         self.stream.write_all(&[self.intr_char]).await
     }
-
-    /// Interact gives control of the child process to the interactive user (the
-    /// human at the keyboard).
-    ///
-    /// Keystrokes are sent to the child process, and
-    /// the `stdout` and `stderr` output of the child process is printed.
-    ///
-    /// When the user types the `escape_character` this method will return control to a running process.
-    /// The escape_character will not be transmitted.
-    /// The default for escape_character is entered as `Ctrl-]`, the very same as BSD telnet.
-    ///
-    /// This simply echos the child `stdout` and `stderr` to the real `stdout` and
-    /// it echos the real `stdin` to the child `stdin`.
-    pub async fn interact(&mut self) -> io::Result<()> {
-        // flush buffers
-        self.flush().await?;
-
-        let stdin = unsafe { std::fs::File::from_raw_fd(std::io::stdin().as_raw_fd()) };
-        let mut stdin_stream = Stream::new(stdin);
-        let mut buf = [0; 512];
-        loop {
-            if let Some(n) = self.try_read(&mut buf).await? {
-                std::io::stdout().write_all(&buf[..n])?;
-            }
-
-            if let Some(n) = stdin_stream.try_read(&mut buf).await? {
-                for i in 0..n {
-                    if buf[i] == ControlCode::GroupSeparator as u8 {
-                        // Ctrl-]
-                        return Ok(());
-                    }
-
-                    self.write_all(&buf[i..i + 1]).await?;
-                }
-            }
-        }
-    }
 }
 
 impl Drop for PtyProcess {
@@ -525,6 +447,14 @@ impl DerefMut for PtyProcess {
     }
 }
 
+fn is_alive(status: Result<WaitStatus>) -> Result<bool> {
+    match status {
+        Ok(status) if status == WaitStatus::StillAlive => Ok(true),
+        Ok(_) | Err(Error::Sys(Errno::ECHILD)) | Err(Error::Sys(Errno::ESRCH)) => Ok(false),
+        Err(err) => Err(err),
+    }
+}
+
 fn set_term_size(fd: i32, cols: u16, rows: u16) -> Result<()> {
     ioctl_write_ptr_bad!(_set_window_size, libc::TIOCSWINSZ, winsize);
 
